Learn R Programming

highD2pop (version 1.0)

CLX.sim.unequalcov: Cai, Liu, and Xia equal means test simulator under unequal covariances

Description

Performs the test in Cai, Liu, and Xia (2014) for testing equality of two mean vectors on multiple data sets generated by build2popData when the population covariances matrices are assumed to be unequal.

Usage

CLX.sim.unequalcov(DATA)

Arguments

DATA
an object returned by build2popData.

Value

TSvalues
values of the test statistic.
pvalues
the p values.

References

Cai, T. T., Liu, W. & Xia, Y. (2014). Two-sample test of high dimensional means under dependence. J. R. Statist. Soc. B.

See Also

CLX.test.unequalcov

Examples

Run this code
	
## Not run: 
# 
# DATA <-build2popData(	
# 	n = 15,
# 	m = 20,
# 	p = 500,
# 	muX = rep(0,500),
# 	muY = rep(0,500),
# 	commoncov = FALSE,
# 	VarScaleY = 1,
# 	dep = "ARMA",
# 	ARMAparms = list(coefs=list(ma=c(.2,.3) , ar=c(.4,-.1))),
# 	LRparm = .75,
# 	S = 25,
# 	innov = function(n,...) rnorm(n,0,1),
# 	heteroscedastic=TRUE,
# 	het.diag = diag(.1 + rexp(500,1/2))
# 	)
# 	
# CLX.sim.unequalcov(DATA)
# 
# ## End(Not run)

Run the code above in your browser using DataLab