Learn R Programming

highD2pop (version 1.0)

ChenQin.test: Chen's and Qin's test for equality of two mean vectors

Description

Performs the test from Chen and Qin (2010) for the equality of two p by 1 population mean vectors given samples of sizes n and m.

Usage

ChenQin.test(X, Y)

Arguments

X
the n by p data matrix for sample one.
Y
the m by p data matrix for sample two.

Value

ChQ
the value of the test statistic.
pvalue
the two-sided p-value for the test statistic.

References

Chen, X. S. and Qin, Y.L. (2010). A two sample test for high dimensional data with applications to gene-set testing. The Annals of Statistics. 38(2):808--835

Examples

Run this code
## Not run: 
# 	
# data(chr1qseg)
# 	
# 	impute <- function(x) 	
# 	{ 	
# 		x[which(is.na(x))] <- mean(x,na.rm=TRUE)
# 		return(x)
# 	}
# 	
# 	X <- apply(chr1qseg$X,2,impute)
# 	Y <- apply(chr1qseg$Y,2,impute)
# 	
# 	ChenQin.test(X,Y)
# 	
# 	## End(Not run)

Run the code above in your browser using DataLab