chr1qsegX, the n=92 by p=400 matrix of copy number measurements for the n=92 long-term survivors, Y, the m=138 by p=400 matrix of copy number measurements for the m=138 short-term survivors, and loc, which gives the locations of the 400 measurements in number of base pairs from the end of the q arm of chromosome 1.